@@ -1,5 +1,5 @@
 from websocket import create_connection
-from .config import HOST, PORT
+from .constants import HOST, PORT
 
 class client:
     def __init__(self, host=HOST, port=PORT):
@@ -8,12 +8,15 @@ class client:
     def close(self):
         self.ws.close()
 
-    def send(self, msg: str) -> str:
+    def send(self, msg: str, get_response=True) -> str:
         """Converts ';' to '\n' and sends the message to the server, returning its response"""
 
         self.ws.send(msg.replace(";", "\n"))
-        resp = self.ws.recv().decode()
 
+        if not get_response:
+            return ""
+
+        resp = self.ws.recv().decode()
         # Return response
         if resp.startswith(">> "):
             if len(resp) > 3:
@@ -24,3 +27,5 @@ class client:
 
         if resp == "Cleared":
             return "Environment cleared!"
+
+        return resp
